@@ -1,10 +1,10 @@
 (function($) {
     var ws, current_mailbox,
         mailboxes = $('#mailboxes');
-    
+
     $.start_web_mail = function (addr) {
         ws = new WebSocket(addr);
-        
+
         ws.onmessage = function(e) {
             var data = $.parseJSON(e.data),
                 list = data.list;
@@ -12,22 +12,18 @@
                 add_mailboxes(list);
             }
         };
-        ws.onopen = function() {
-            // Send empty message so that we connect this client
-            ws.send('');
-        };
     }
-    
+
     function add_mailboxes (list) {
         var m = mailboxes.html('');
         $.each(list, function () {
             m.append('<li><a class="mailbox" href="#">' + this + '</a></li>');
         });
     }
-    
+
     $(document).on('click', 'a.mailbox', function () {
         var elem = $(this);
             name = elem.html();
         ws.send(JSON.stringify({'mailbox': name}));
     });
-}(jQuery));
\ No newline at end of file
+}(jQuery));
