@@ -60,13 +60,12 @@ By default, the list of hooks only contains a callback to start the
 '''
 import os
 import sys
-from hashlib import sha1
 from inspect import getfile
 from functools import partial
 from collections import namedtuple
 
 import pulsar
-from pulsar import (get_actor, coroutine_return, Config, async,
+from pulsar import (get_actor, coroutine_return, Config, task, From,
                     multi_async, Future, ImproperlyConfigured)
 from pulsar.utils.structures import OrderedDict
 
@@ -94,20 +93,21 @@ def get_application(name):
 
 
 def _get_remote_app(actor, name):
-    cfg = yield actor.send('arbiter', 'run', _get_app, name)
+    cfg = yield From(actor.send('arbiter', 'run', _get_app, name))
     coroutine_return(cfg.app() if cfg else None)
 
 
 def _get_app(arbiter, name, safe=True):
     monitor = arbiter.get_actor(name)
     if monitor:
-        cfg = yield monitor.start_event
+        cfg = yield From(monitor.start_event)
         if safe:
             coroutine_return(cfg)
         else:
             coroutine_return(monitor.app)
 
 
+@task
 def monitor_start(self, exc=None):
     start_event = self.start_event
     if exc:
@@ -120,7 +120,7 @@ def monitor_start(self, exc=None):
         self.bind_event('stopping', monitor_stopping)
         for callback in when_monitor_start:
             yield callback(self)
-        self.monitor_task = lambda: app.monitor_task(self)
+        self.bind_event('periodic_task', app.monitor_task)
         yield app.monitor_start(self)
         if not self.cfg.workers:
             yield app.worker_start(self)
@@ -132,6 +132,7 @@ def monitor_start(self, exc=None):
         start_event.set_result(result)
 
 
+@task
 def monitor_stopping(self, exc=None):
     if not self.cfg.workers:
         yield self.app.worker_stopping(self)
@@ -311,7 +312,6 @@ class Configurator(object):
         # get the actor if available and override default cfg values with those
         # from the actor
         actor = get_actor()
-        cfg = self.cfg
         if actor and actor.is_running():
             # actor available and running.
             # Unless argv is set, skip parsing
@@ -348,7 +348,7 @@ class Configurator(object):
 
     def start(self):
         '''Invoked the application callable method and start
-        the :class:`.Arbiter` if it wasn't already started.
+        the ``arbiter`` if it wasn't already started.
 
         It returns a :class:`~asyncio.Future` called back once the
         application/applications are running. It returns ``None`` if
@@ -398,8 +398,8 @@ class Application(Configurator):
       not be overwritten, instead one should overwrites the application
       hooks available.
     * When an :class:`Application` is called for the first time,
-      a new :class:`.Monitor` instance is added to the
-      :class:`.Arbiter`, ready to perform its duties.
+      a new ``monitor`` is added to the ``arbiter``,
+      ready to perform its duties.
 
     :parameter callable: Initialise the :attr:`callable` attribute.
     :parameter load_config: If ``False`` the :meth:`~Configurator.load_config`
@@ -441,10 +441,10 @@ class Application(Configurator):
 
         If an ``actor`` is available (either via the function argument or via
         the :func:`~pulsar.async.actor.get_actor` function) it must be
-        :class:`.Arbiter`, otherwise this call is no-op.
+        ``arbiter``, otherwise this call is no-op.
 
         If no actor is available, it means this application starts
-        pulsar engine by creating the :class:`.Arbiter` with its
+        pulsar engine by creating the ``arbiter`` with its
         :ref:`global settings <setting-section-global-server-settings>`
         copied to the arbiter :class:`.Config` container.
 
