@@ -1,4 +1,4 @@
-from pulsar import Event, wait_complete, chain_future, add_callback, task
+from pulsar import Event, chain_future, add_callback, task
 
 from .query import AbstractQuery, Query, QueryError, ModelNotFound
 from ..store import Command
@@ -131,7 +131,7 @@ class Manager(AbstractQuery):
         '''
         return self.query_class(self)
 
-    @wait_complete
+    @task
     def get(self, *args, **kw):
         '''Get a single model
         '''
@@ -174,7 +174,7 @@ class Manager(AbstractQuery):
         '''Create a new instance of :attr:`_model` and commit to server.
         '''
         with self._mapper.begin() as t:
-            model = t.add(self(*args, **kwargs))
+            t.add(self(*args, **kwargs))
         return t.wait(lambda models: models[self._store][0])
     new = create
     insert = new
