@@ -33,7 +33,7 @@ CouchDBStore
 '''
 from base64 import b64encode, b64decode
 
-from pulsar import asyncio, coroutine_return, wait_complete, multi_async
+from pulsar import asyncio, coroutine_return, task, multi_async
 from pulsar.utils.system import json
 from pulsar.apps.data import Store, Command, register_store
 from pulsar.utils.pep import zip
@@ -90,7 +90,7 @@ class CouchDBStore(CouchDBMixin, Store):
                             views=views,
                             language=language or 'javascript', **kwargs)
 
-    @wait_complete
+    @task
     def design_delete(self, name):
         '''Delete an existing design document at ``name``.
         '''
@@ -103,9 +103,14 @@ class CouchDBStore(CouchDBMixin, Store):
     def design_info(self, name):
         return self.request('get', self._database, '_design', name, '_info')
 
-    # DOCUMENTS
-    def update_document(self, document):
-        return self.request('post', self._database, **document)
+    # DOCUMENTS API
+    def get_document(self, dbname, pkvalue):
+        '''Fetch a document from ``dbname`` with id ``pkvalue``
+        '''
+        return self.request('get', dbname, pkvalue)
+
+    def update_document(self, dbname, document):
+        return self.request('post', dbname, **document)
 
     def update_documents(self, dbname, documents, new_edits=True):
         '''Bulk update/insert of documents in a database
@@ -166,7 +171,7 @@ class CouchDBStore(CouchDBMixin, Store):
                 raise errors[0]
         coroutine_return(models)
 
-    @wait_complete
+    @task
     def get_model(self, manager, pkvalue):
         try:
             data = yield self.request('get', self._database, pkvalue)
@@ -213,7 +218,7 @@ class CouchDBStore(CouchDBMixin, Store):
         return super(CouchDBStore, self).build_model(manager, *args, **kwargs)
 
     # INTERNALS
-    @wait_complete
+    @task
     def request(self, method, *bits, **kwargs):
         '''Execute the HTTP request'''
         if self._password:
@@ -268,8 +273,6 @@ class CouchDBStore(CouchDBMixin, Store):
             for key, value in meta.store_data(model, self, action):
                 yield _id if key == pkname else key, value
             yield 'Type', meta.table_name
-        if '_rev' in model:
-            yield '_rev', model['_rev']
 
 
 register_store("couchdb", "pulsar.apps.data.stores.CouchDBStore")
