@@ -269,7 +269,7 @@ from io import StringIO, BytesIO
 
 import pulsar
 from pulsar import (AbstractClient, Pool, coroutine_return, task, Connection,
-                    get_event_loop, ProtocolConsumer, new_event_loop)
+                    ProtocolConsumer, From)
 from pulsar.utils.system import json
 from pulsar.utils.pep import native_str, is_string, to_bytes, ispy3k
 from pulsar.utils.structures import mapping_iterator
@@ -279,13 +279,18 @@ from pulsar.utils.multipart import parse_options_header
 from pulsar.utils.httpurl import (urlparse, parse_qsl, responses,
                                   http_parser, ENCODE_URL_METHODS,
                                   encode_multipart_formdata, urlencode,
-                                  Headers, urllibr, get_environ_proxies,
+                                  Headers, get_environ_proxies,
                                   choose_boundary, urlunparse, request_host,
                                   is_succesful, HTTPError, URLError,
                                   get_hostport, cookiejar_from_dict,
                                   host_no_default_port, DEFAULT_CHARSET,
                                   JSON_CONTENT_TYPES)
 
+try:
+    from pulsar.apps import greenio
+except ImportError:
+    greenio = None
+
 from .plugins import (handle_cookies, handle_100, handle_101, handle_redirect,
                       Tunneling, TooManyRedirects)
 
@@ -456,10 +461,9 @@ class HttpRequest(RequestBase):
         if self._scheme in tls_schemes:
             self._ssl = client.ssl_context(**ignored)
         self.headers = client.get_headers(self, headers)
-        if client.cookies:
-            client.cookies.add_cookie_header(self)
+        cookies = cookiejar_from_dict(client.cookies, cookies)
         if cookies:
-            cookiejar_from_dict(cookies).add_cookie_header(self)
+            cookies.add_cookie_header(self)
         self.unredirected_headers['host'] = host_no_default_port(self._scheme,
                                                                  self._netloc)
         client.set_proxy(self)
@@ -913,6 +917,13 @@ class HttpClient(AbstractClient):
 
         Dictionary of connection pools for different hosts
 
+    .. attribute:: green
+
+        If ``True`` the requests are processed using the
+        :mod:`~pulsar.apps.greenio` application. When operating in this mode,
+        the :class:`.HttpClient` must be used from a greenlet ather than the
+        main one.
+
     .. attribute:: DEFAULT_HTTP_HEADERS
 
         Default headers for this :class:`HttpClient`
@@ -959,7 +970,7 @@ class HttpClient(AbstractClient):
                  max_redirects=10, decompress=True, version=None,
                  websocket_handler=None, parser=None, trust_env=True,
                  loop=None, client_version=None, timeout=None,
-                 pool_size=10):
+                 pool_size=10, green=False):
         super(HttpClient, self).__init__(loop)
         self.client_version = client_version or self.client_version
         self.connection_pools = {}
@@ -971,6 +982,7 @@ class HttpClient(AbstractClient):
         self.cookies = cookiejar_from_dict(cookies)
         self.decompress = decompress
         self.version = version or self.version
+        self.green = green and greenio
         dheaders = self.DEFAULT_HTTP_HEADERS.copy()
         dheaders['user-agent'] = self.client_version
         if headers:
@@ -991,11 +1003,14 @@ class HttpClient(AbstractClient):
                                'ca_certs': ca_certs}
         self.http_parser = parser or http_parser
         # Add hooks
-        self.bind_event('pre_request', Tunneling())
+        self.bind_event('pre_request', Tunneling(self._loop))
         self.bind_event('on_headers', handle_101)
         self.bind_event('on_headers', handle_100)
         self.bind_event('on_headers', handle_cookies)
         self.bind_event('post_request', handle_redirect)
+        # greenlet
+        if self.green:
+            self.request = partial(green_request, self.request)
 
     @property
     def websocket_key(self):
@@ -1177,8 +1192,12 @@ class HttpClient(AbstractClient):
                 request.set_proxy(p.scheme, p.netloc)
 
     def _connect(self, host, port, ssl):
-        _, connection = yield self._loop.create_connection(
-            self.create_protocol, host, port, ssl=ssl)
+        _, connection = yield From(self._loop.create_connection(
+            self.create_protocol, host, port, ssl=ssl))
         # Wait for the connection made event
-        yield connection.event('connection_made')
+        yield From(connection.event('connection_made'))
         coroutine_return(connection)
+
+
+def green_request(request, method, url, **params):
+    return greenio.wait(request(method, url, **params))
