@@ -1,7 +1,8 @@
 '''Asynchronous application for serving requests
 on sockets. This is the base class of :class:`.WSGIServer`.
-All is needed by a :class:`SocketServer` is a callable which build a
-:class:`.ProtocolConsumer` for each new client request received.
+All is needed by a :class:`.SocketServer` application is a callable
+which build a :class:`.ProtocolConsumer` for each new client request
+received.
 This is an example of a script for an Echo server::
 
     import pulsar
@@ -14,7 +15,7 @@ This is an example of a script for an Echo server::
         SocketServer(EchoServerProtocol).start()
 
 Check the :ref:`echo server example <tutorials-writing-clients>` for detailed
-implementation of the ``.EchoServerProtocol`` class.
+implementation of the ``EchoServerProtocol`` class.
 
 .. _socket-server-settings:
 
@@ -81,7 +82,7 @@ When running a :class:`SocketServer` in threading mode::
 
 the number of :class:`.Actor` serving the application is set
 to ``0`` so that the application is actually served by the
-:class:`.Arbiter` event-loop (we refer this to a single process server).
+arbiter event-loop (we refer this to a single process server).
 This configuration is used when debugging, testing, benchmarking or on small
 load servers.
 
@@ -101,8 +102,9 @@ from random import lognormvariate
 from functools import partial
 
 import pulsar
-from pulsar import asyncio, TcpServer, DatagramServer, Connection
-from pulsar.utils.internet import parse_address, SSLContext, format_address
+from pulsar import (asyncio, From, TcpServer, DatagramServer, Connection,
+                    ImproperlyConfigured)
+from pulsar.utils.internet import parse_address, SSLContext
 from pulsar.utils.config import pass_through
 
 
@@ -216,28 +218,33 @@ class SocketServer(pulsar.Application):
                 or cfg.concurrency == 'thread'):
             cfg.set('workers', 0)
         if not cfg.address:
-            raise pulsar.ImproperlyConfigured('Could not open a socket. '
-                                              'No address to bind to')
+            raise ImproperlyConfigured('Could not open a socket. '
+                                       'No address to bind to')
         ssl = None
         if cfg.cert_file or cfg.key_file:
             if cfg.cert_file and not os.path.exists(cfg.cert_file):
-                raise ValueError('cert_file "%s" does not exist' %
-                                 cfg.cert_file)
+                raise ImproperlyConfigured('cert_file "%s" does not exist' %
+                                           cfg.cert_file)
             if cfg.key_file and not os.path.exists(cfg.key_file):
-                raise ValueError('key_file "%s" does not exist' % cfg.key_file)
+                raise ImproperlyConfigured('key_file "%s" does not exist' %
+                                           cfg.key_file)
             ssl = SSLContext(keyfile=cfg.key_file, certfile=cfg.cert_file)
         address = parse_address(self.cfg.address)
         # First create the sockets
-        server = yield loop.create_server(asyncio.Protocol, *address)
-        addresses = []
-        sockets = []
-        for sock in server.sockets:
-            addresses.append(sock.getsockname())
-            sockets.append(sock)
-            server.loop.remove_reader(sock.fileno())
-        monitor.sockets = sockets
-        monitor.ssl = ssl
-        cfg.addresses = addresses
+        try:
+            server = yield From(loop.create_server(asyncio.Protocol, *address))
+        except socket.error as e:
+            raise ImproperlyConfigured(e)
+        else:
+            addresses = []
+            sockets = []
+            for sock in server.sockets:
+                addresses.append(sock.getsockname())
+                sockets.append(sock)
+                loop.remove_reader(sock.fileno())
+            monitor.sockets = sockets
+            monitor.ssl = ssl
+            cfg.addresses = addresses
 
     def actorparams(self, monitor, params):
         params.update({'sockets': monitor.sockets, 'ssl': monitor.ssl})
@@ -280,9 +287,10 @@ class SocketServer(pulsar.Application):
         server = self.server_factory(self.protocol_factory(),
                                      worker._loop,
                                      sockets=sockets,
-                                     max_connections=max_requests,
+                                     max_requests=max_requests,
                                      keep_alive=cfg.keep_alive,
-                                     name=self.name)
+                                     name=self.name,
+                                     logger=self.logger)
         for event in ('connection_made', 'pre_request', 'post_request',
                       'connection_lost'):
             callback = getattr(cfg, event)
@@ -326,8 +334,8 @@ class UdpSocketServer(SocketServer):
                                               'No address to bind to')
         address = parse_address(self.cfg.address)
         # First create the sockets
-        t, _ = yield loop.create_datagram_endpoint(asyncio.DatagramProtocol,
-                                                   address)
+        t, _ = yield From(loop.create_datagram_endpoint(
+            asyncio.DatagramProtocol, address))
         sock = t.get_extra_info('socket')
         assert loop.remove_reader(sock.fileno())
         monitor.sockets = [WrapTransport(t)]
@@ -355,7 +363,8 @@ class UdpSocketServer(SocketServer):
                                      worker._loop,
                                      sockets=worker.sockets,
                                      max_requests=max_requests,
-                                     name=self.name)
+                                     name=self.name,
+                                     logger=self.logger)
         server.bind_event('stop', lambda _, **kw: worker.stop())
         for event in ('pre_request', 'post_request'):
             callback = getattr(cfg, event)
