@@ -69,7 +69,7 @@ import mimetypes
 from email.utils import parsedate_tz, mktime_tz
 
 from pulsar.utils.httpurl import http_date, CacheControl
-from pulsar.utils.structures import AttributeDictionary, OrderedDict
+from pulsar.utils.structures import OrderedDict
 from pulsar.utils.slugify import slugify
 from pulsar import Http404, HttpException
 
@@ -103,7 +103,7 @@ def update_args(urlargs, args):
 
 class RouterParam(object):
     '''A :class:`RouterParam` is a way to flag a :class:`Router` parameter
-    so that children can retrieve the value if they don't define their own.
+    so that children can inherit the value if they don't define their own.
 
     A :class:`RouterParam` is always defined as a class attribute and it
     is processed by the :class:`Router` metaclass and stored in a dictionary
@@ -123,17 +123,17 @@ class RouterType(type):
     ''':class:`Router` metaclass.'''
     def __new__(cls, name, bases, attrs):
         rule_methods = get_roule_methods(attrs.items())
-        parameters = {}
+        defaults = {}
         for key, value in list(attrs.items()):
             if isinstance(value, RouterParam):
-                parameters[key] = attrs.pop(key).value
+                defaults[key] = attrs.pop(key).value
         no_rule = set(attrs) - set((x[0] for x in rule_methods))
         base_rules = []
         for base in reversed(bases):
-            if hasattr(base, 'parameters'):
-                params = base.parameters.copy()
-                params.update(parameters)
-                parameters = params
+            if hasattr(base, 'defaults'):
+                params = base.defaults.copy()
+                params.update(defaults)
+                defaults = params
             if hasattr(base, 'rule_methods'):
                 items = base.rule_methods.items()
             else:
@@ -152,7 +152,7 @@ class RouterType(type):
             rule_methods = sorted(rule_methods.items(),
                                   key=lambda x: x[1].order)
         attrs['rule_methods'] = OrderedDict(rule_methods)
-        attrs['parameters'] = parameters
+        attrs['defaults'] = defaults
         return super(RouterType, cls).__new__(cls, name, bases, attrs)
 
 
@@ -170,9 +170,6 @@ class Router(RouterType('RouterBase', (object,), {})):
     :param routes: Optional :class:`Router` instances which are added to the
         children :attr:`routes` of this router.
     :param parameters: Optional parameters for this router.
-        They are stored in the :attr:`parameters` attribute with the
-        exception of :attr:`response_content_types` and
-        :attr:`response_wrapper`
 
     .. attribute:: rule_methods
 
@@ -207,17 +204,10 @@ class Router(RouterType('RouterBase', (object,), {})):
                 ...
                 return handler(request)
 
-    .. attribute:: parameters
-
-        A :class:`.AttributeDictionary` of parameters for
-        this :class:`Router`. Parameters are created at initialisation from
-        the ``parameters`` class attribute and the key-valued parameters
-        passed to the ``__init__`` method which are available in the
-        class ``parameters`` attribute.
     '''
     _creation_count = 0
     _parent = None
-    _name = None
+    name = None
 
     response_content_types = RouterParam(None)
     response_wrapper = RouterParam(None)
@@ -228,24 +218,19 @@ class Router(RouterType('RouterBase', (object,), {})):
         if not isinstance(rule, Route):
             rule = Route(rule)
         self._route = rule
-        self._name = parameters.pop('name', rule.name)
+        parameters.setdefault('name', rule.name)
+        self._set_params(parameters)
         self.routes = []
         # add routes specified via the initialiser first
         for router in routes:
             self.add_child(router)
-        # copy parameters
-        self.parameters = AttributeDictionary(self.parameters)
+
         for name, rule_method in self.rule_methods.items():
             rule, method, params, _, _ = rule_method
             rparameters = params.copy()
             handler = getattr(self, name)
-            router = self.add_child(self.make_router(rule, **rparameters))
-            setattr(router, method, handler)
-        for name, value in parameters.items():
-            if name in self.parameters:
-                self.parameters[name] = value
-            else:
-                setattr(self, slugify(name, separator='_'), value)
+            self.add_child(self.make_router(rule, method=method,
+                                            handler=handler, **rparameters))
 
     @property
     def route(self):
@@ -270,16 +255,6 @@ class Router(RouterType('RouterBase', (object,), {})):
         else:
             return self._route
 
-    @property
-    def name(self):
-        '''The name of this :class:`Router`.
-
-        This attribute can be specified during initialisation.
-        If available, it can be used to retrieve a child router
-        by name via the :meth:`get_route` method.
-        '''
-        return self._name
-
     @property
     def root(self):
         '''The root :class:`Router` for this :class:`Router`.'''
@@ -330,9 +305,19 @@ class Router(RouterType('RouterBase', (object,), {})):
         If the parameter is not available, retrieve the parameter from the
         :attr:`parent` :class:`Router` if it exists.
         '''
-        if not name.startswith('_'):
-            return self._get_router_parameter(name, False)
-        self._no_param(name)
+        if name in self.defaults:
+            if self._parent:
+                try:
+                    return getattr(self._parent, name)
+                except AttributeError:
+                    pass
+            return self.defaults[name]
+
+        if self._parent:
+            return getattr(self._parent, name)
+        else:
+            raise AttributeError("'%s' object has no attribute '%s'" %
+                                 (self.__class__.__name__, name))
 
     def content_type(self, request):
         '''Evaluate the content type for the response to a client ``request``.
@@ -403,17 +388,18 @@ class Router(RouterType('RouterBase', (object,), {})):
         '''
         assert isinstance(router, Router), 'Not a valid Router'
         assert router is not self, 'cannot add self to children'
+
+        for r in self.routes:
+            if r == router:
+                return r
+            elif r._route == router._route:
+                raise ValueError('Cannot add route %s. Already avalable' %
+                                 r._route)
         #
         # Remove from previous parent
         if router.parent:
             router.parent.remove_child(router)
         router._parent = self
-        # Loop over available routers to check it the router
-        # is already available
-        for r in self.routes:
-            if r.route == router.route:
-                r.parameters.update(router.parameters)
-                return r
         self.routes.append(router)
         return router
 
@@ -456,30 +442,38 @@ class Router(RouterType('RouterBase', (object,), {})):
             parent = parent._parent
         return parent is not None
 
-    def make_router(self, rule, cls=None, **params):
+    def make_router(self, rule, method=None, handler=None, cls=None,
+                    name=None, **params):
         '''Create a new :class:`.Router` from a ``rule`` and parameters.
 
         This method is used during initialisation when building child
         Routers from the :attr:`rule_methods`.
         '''
         cls = cls or Router
-        return cls(rule, **params)
+        router = cls(rule, name=name, **params)
+        for r in self.routes:
+            if r._route == router._route:
+                if isinstance(r, cls):
+                    router = r
+                    router._set_params(params)
+                    break
+        if method and handler:
+            setattr(router, method, handler)
+        return router
 
-    def _no_param(self, name):
-        raise AttributeError("'%s' object has no attribute '%s'" %
-                             (self.__class__.__name__, name))
+    @classmethod
+    def copy(cls):
+        '''Create a copy of this router without routes'''
+        newcls = RouterType(cls.__name__ + 'Copy', (cls,), {})
+        newcls.rule_methods.clear()
+        return newcls
 
-    def _get_router_parameter(self, name, safe=True):
-        value = self.parameters.get(name)
-        if value is None:
-            if self._parent:
-                return self._parent._get_router_parameter(name, safe)
-            elif name in self.parameters:
-                return value
-            elif not safe:
-                self._no_param(name)
-        else:
-            return value
+    # INTERNALS
+    def _set_params(self, parameters):
+        for name, value in parameters.items():
+            if name not in self.defaults:
+                name = slugify(name, separator='_')
+            setattr(self, name, value)
 
 
 class MediaMixin(object):
