@@ -56,8 +56,9 @@ KNOWN_SETTINGS_ORDER = []
 def pass_through(arg):
     '''A dummy function accepting one parameter only.
 
-It does nothing and it is used as default by
-:ref:`Application Hooks <setting-section-application-hooks>`.'''
+    It does nothing and it is used as default by
+    :ref:`Application Hooks <setting-section-application-hooks>`.
+    '''
     pass
 
 
@@ -354,7 +355,7 @@ class Config(object):
     def clone(self):
         return pickle.loads(pickle.dumps(self))
 
-    def configured_logger(self, name=None):
+    def configured_logger(self, name=None, replace=False):
         '''Configured logger.
         '''
         loggers = {}
@@ -405,7 +406,8 @@ class Config(object):
                                        config=self.logconfig,
                                        level=namespaces[namespace],
                                        handlers=loghandlers,
-                                       rootlevel=internal_level)
+                                       rootlevel=internal_level,
+                                       replace=replace)
             loggers[namespace] = logger
         return loggers.get(name)
 
@@ -1121,8 +1123,11 @@ Application hooks are functions which can be specified in a
 These tasks can be scheduled when events occurs or at every event loop of
 the various components of a pulsar application.
 
-All application hooks are functions which accept one parameter only, the actor
-invoking the function.
+All application hooks are functions which accept one positional
+parameter and one key-valued parameter ``exc`` when an exception occurs::
+
+    def hook(arg, exc=None):
+        ...
 
 Like worker process settings, each application can specify their own.
 '''
@@ -1134,11 +1139,7 @@ class Postfork(Setting):
     validator = validate_callable(1)
     type = "callable"
     default = staticmethod(pass_through)
-    desc = """\
-        Called just after a worker has been forked.
-
-        The event loop is not yet available.
-        """
+    desc = 'Called just after a worker has been forked'
 
 
 class WhenReady(Setting):
@@ -1147,12 +1148,7 @@ class WhenReady(Setting):
     validator = validate_callable(1)
     type = "callable"
     default = staticmethod(pass_through)
-    desc = """\
-        Called just before a worker starts its event loop.
-
-        This is a chance to setup :class:`pulsar.EventLoop` callbacks which
-        can run periodically, at every loop or when some defined events occur.
-        """
+    desc = 'Called just before a worker starts running its event loop'
 
 
 class WhenExit(Setting):
