@@ -1,12 +1,10 @@
 '''Utilities for HTML and text manipulation.
 '''
-import re
-from unicodedata import normalize
-
 from .system import json
 from .pep import (ispy3k, native_str, to_string, iteritems, is_string,
                   string_type)
 
+
 NOTHING = ('', b'', None)
 '''Tuple of elements considered as null.'''
 INLINE_TAGS = set(('input', 'link', 'meta', 'hr'))
@@ -35,14 +33,6 @@ def child_tag(tag):
     return HTML_CHILDREN_TAG.get(tag)
 
 
-def slugify(value, rtx='_'):
-    '''Normalizes string, removes non-alpha characters,
-and converts spaces to ``rtx`` character (hyphens or underscore).'''
-    value = normalize('NFKD', to_string(value)).encode('ascii', 'ignore')
-    value = to_string(re.sub('[^\w\s-]', rtx, value.decode()).strip())
-    return re.sub('[-\s]+', rtx, value)
-
-
 def mark_safe(v):
     '''Mar a string ``v`` as safe. A safe string won't be escaped by the
 :func:`escape` function.'''
